@@ -1,10 +1,10 @@
-from bread.utils.urls import autopath
+from bread.utils.urls import autopath, default_model_paths
 
 import basxconnect.mailer_integration.views
 from basxconnect.mailer_integration import models
 
 urlpatterns = [
-    autopath(basxconnect.mailer_integration.views.mailchimp_view),
+    autopath(basxconnect.mailer_integration.views.mailer_synchronization_view),
     autopath(
         basxconnect.mailer_integration.views.EditMailingPreferencesView.as_view(
             model=models.MailingPreferences
@@ -15,4 +15,5 @@ urlpatterns = [
             model=models.MailingPreferences
         )
     ),
+    *default_model_paths(models.SynchronizationResult),
 ]
